@@ -667,10 +667,10 @@ def print_biogene( gene=None, fh=None, source=None, on=None ):
 
         # are there polypeptides?
         for polypeptide in sorted(RNA.polypeptides()):
-            # Original "if polypeptides.location is None" will always False
-            # Changed type checking to list checking
-            if len(polypeptide.locations == 0):
+            if len(polypeptide.locations) == 0:
                 polypeptide_loc = RNA_loc
+            else:
+                polypeptide_loc = polypeptide.location_on(on)
 
             annot = polypeptide.annotation
             assertions = dict()
